[latexila] LaTeX commands: rename latex-menu to latex-commands in liblatexila
- From: Sébastien Wilmet <swilmet src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [latexila] LaTeX commands: rename latex-menu to latex-commands in liblatexila
- Date: Wed, 25 Oct 2017 14:43:01 +0000 (UTC)
commit 573626e6904554179d2c4c4443afaf661775b3a5
Author: Sébastien Wilmet <swilmet gnome org>
Date: Wed Oct 25 16:37:07 2017 +0200
LaTeX commands: rename latex-menu to latex-commands in liblatexila
It is not just the menus, it is also the Edit toolbar.
docs/reference/latexila-docs.xml | 2 +-
docs/reference/latexila-sections.txt | 6 ++--
po/POTFILES.in | 2 +-
src/latex_menu.vala | 4 +-
src/liblatexila/Makefile.am | 4 +-
...xila-latex-menu.c => latexila-latex-commands.c} | 22 ++++++++++----------
...xila-latex-menu.h => latexila-latex-commands.h} | 16 +++++++-------
src/liblatexila/latexila.h | 2 +-
8 files changed, 29 insertions(+), 29 deletions(-)
---
diff --git a/docs/reference/latexila-docs.xml b/docs/reference/latexila-docs.xml
index fd110bb..bf1f88d 100644
--- a/docs/reference/latexila-docs.xml
+++ b/docs/reference/latexila-docs.xml
@@ -36,7 +36,7 @@
<chapter>
<title>Misc</title>
- <xi:include href="xml/latex-menu.xml"/>
+ <xi:include href="xml/latex-commands.xml"/>
<xi:include href="xml/synctex.xml"/>
<xi:include href="xml/utils.xml"/>
</chapter>
diff --git a/docs/reference/latexila-sections.txt b/docs/reference/latexila-sections.txt
index 61af372..113a175 100644
--- a/docs/reference/latexila-sections.txt
+++ b/docs/reference/latexila-sections.txt
@@ -131,9 +131,9 @@ latexila_build_view_get_type
</SECTION>
<SECTION>
-<FILE>latex-menu</FILE>
-latexila_latex_menu_add_actions
-latexila_latex_menu_insert_text
+<FILE>latex-commands</FILE>
+latexila_latex_commands_add_actions
+latexila_latex_commands_insert_text
</SECTION>
<SECTION>
diff --git a/po/POTFILES.in b/po/POTFILES.in
index 0964a41..bdc2ab6 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -31,7 +31,7 @@ src/liblatexila/latexila-build-tools.c
src/liblatexila/latexila-build-tools-default.c
src/liblatexila/latexila-build-tools-personal.c
src/liblatexila/latexila-build-view.c
-src/liblatexila/latexila-latex-menu.c
+src/liblatexila/latexila-latex-commands.c
src/liblatexila/latexila-post-processor-all-output.c
src/liblatexila/latexila-post-processor.c
src/liblatexila/latexila-post-processor-latex.c
diff --git a/src/latex_menu.vala b/src/latex_menu.vala
index d2e5a45..a3406bf 100644
--- a/src/latex_menu.vala
+++ b/src/latex_menu.vala
@@ -463,7 +463,7 @@ public class LatexMenu : Gtk.ActionGroup
/* GActions */
- Latexila.latex_menu_add_actions (main_window);
+ Latexila.latex_commands_add_actions (main_window);
// LaTeX: Sectioning
Amtk.utils_bind_g_action_to_gtk_action (main_window, "latex-command-with-braces::part",
@@ -554,7 +554,7 @@ public class LatexMenu : Gtk.ActionGroup
Tepl.ApplicationWindow tepl_window =
Tepl.ApplicationWindow.get_from_gtk_application_window (main_window);
- Latexila.latex_menu_insert_text (tepl_window, text_before, text_after,
+ Latexila.latex_commands_insert_text (tepl_window, text_before, text_after,
text_if_no_selection);
}
diff --git a/src/liblatexila/Makefile.am b/src/liblatexila/Makefile.am
index e19facb..578a6c7 100644
--- a/src/liblatexila/Makefile.am
+++ b/src/liblatexila/Makefile.am
@@ -27,7 +27,7 @@ liblatexila_headers = \
latexila-build-tools-default.h \
latexila-build-tools-personal.h \
latexila-build-view.h \
- latexila-latex-menu.h \
+ latexila-latex-commands.h \
latexila-post-processor.h \
latexila-post-processor-all-output.h \
latexila-post-processor-latex.h \
@@ -48,7 +48,7 @@ liblatexila_sources = \
latexila-build-tools-default.c \
latexila-build-tools-personal.c \
latexila-build-view.c \
- latexila-latex-menu.c \
+ latexila-latex-commands.c \
latexila-post-processor.c \
latexila-post-processor-all-output.c \
latexila-post-processor-latex.c \
diff --git a/src/liblatexila/latexila-latex-menu.h b/src/liblatexila/latexila-latex-commands.h
similarity index 58%
rename from src/liblatexila/latexila-latex-menu.h
rename to src/liblatexila/latexila-latex-commands.h
index 8d1be68..d44ca04 100644
--- a/src/liblatexila/latexila-latex-menu.h
+++ b/src/liblatexila/latexila-latex-commands.h
@@ -17,20 +17,20 @@
* along with LaTeXila. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef LATEXILA_LATEX_MENU_H
-#define LATEXILA_LATEX_MENU_H
+#ifndef LATEXILA_LATEX_COMMANDS_H
+#define LATEXILA_LATEX_COMMANDS_H
#include <tepl/tepl.h>
G_BEGIN_DECLS
-void latexila_latex_menu_add_actions (GtkApplicationWindow *gtk_window);
+void latexila_latex_commands_add_actions (GtkApplicationWindow *gtk_window);
-void latexila_latex_menu_insert_text (TeplApplicationWindow *tepl_window,
- const gchar *text_before,
- const gchar *text_after,
- const gchar *text_if_no_selection);
+void latexila_latex_commands_insert_text (TeplApplicationWindow *tepl_window,
+ const gchar *text_before,
+ const gchar *text_after,
+ const gchar *text_if_no_selection);
G_END_DECLS
-#endif /* LATEXILA_LATEX_MENU_H */
+#endif /* LATEXILA_LATEX_COMMANDS_H */
diff --git a/src/liblatexila/latexila.h b/src/liblatexila/latexila.h
index 41a6f6f..6ea593c 100644
--- a/src/liblatexila/latexila.h
+++ b/src/liblatexila/latexila.h
@@ -33,7 +33,7 @@
#include "latexila-build-tools-default.h"
#include "latexila-build-tools-personal.h"
#include "latexila-build-view.h"
-#include "latexila-latex-menu.h"
+#include "latexila-latex-commands.h"
#include "latexila-post-processor.h"
#include "latexila-post-processor-all-output.h"
#include "latexila-post-processor-latex.h"
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/liblatexila/latexila-latex-menu.c b/src/liblatexila/latexila-latex-commands.c
similarity index 88%
rename from src/liblatexila/latexila-latex-menu.c
rename to src/liblatexila/latexila-latex-commands.c
index 6c826b8..203d91b 100644
--- a/src/liblatexila/latexila-latex-menu.c
+++ b/src/liblatexila/latexila-latex-commands.c
@@ -18,22 +18,22 @@
*/
/**
* SECTION:latex-menu
* @title: LatexilaLatexMenu
* @short_description: LaTeX and Math menus
*/
-#include "latexila-latex-menu.h"
+#include "latexila-latex-commands.h"
#include "latexila-utils.h"
/* Temporarily public, will be made private when all GActions for the LaTeX and
* Math menus are implemented.
*/
void
-latexila_latex_menu_insert_text (TeplApplicationWindow *tepl_window,
- const gchar *text_before,
- const gchar *text_after,
- const gchar *text_if_no_selection)
+latexila_latex_commands_insert_text (TeplApplicationWindow *tepl_window,
+ const gchar *text_before,
+ const gchar *text_after,
+ const gchar *text_if_no_selection)
{
TeplView *view;
GtkTextBuffer *buffer;
@@ -136,19 +136,19 @@ latex_command_with_braces_cb (GSimpleAction *action,
command = g_variant_get_string (parameter, NULL);
text_before = g_strdup_printf ("\\%s{", command);
- latexila_latex_menu_insert_text (tepl_window, text_before, "}", NULL);
+ latexila_latex_commands_insert_text (tepl_window, text_before, "}", NULL);
g_free (text_before);
}
/**
- * latexila_latex_menu_add_actions:
+ * latexila_latex_commands_add_actions:
* @gtk_window: a #GtkApplicationWindow.
*
* Adds the #GAction's related to the LaTeX and Math menus.
*/
void
-latexila_latex_menu_add_actions (GtkApplicationWindow *gtk_window)
+latexila_latex_commands_add_actions (GtkApplicationWindow *gtk_window)
{
TeplApplicationWindow *tepl_window;
@@ -18,22 +18,22 @@
*/
/**
- * SECTION:latex-menu
- * @title: LatexilaLatexMenu
- * @short_description: LaTeX and Math menus
+ * SECTION:latex-commands
+ * @title: LaTeX commands
+ * @short_description: LaTeX menu, Math menu and Edit toolbar
*/